@@ -60,6 +60,8 @@ __all__ = (
     "TableStatusType",
     "TimeToLiveStatusType",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -425,3 +427,5 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["list_backups", "list_tables", "list_tags_of_resource", "query", "scan"]
+WaiterName = Literal["table_exists", "table_not_exists"]
